@@ -8,15 +8,20 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.assets._jsii
+import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
+import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-glue", "1.121.0", __name__[0:-6], "aws-glue@1.121.0.jsii.tgz"
+    "@aws-cdk/aws-glue", "1.124.0", __name__[0:-6], "aws-glue@1.124.0.jsii.tgz"
 )
 
 __all__ = [
